import matplotlib as mpl
from IPython.display import HTML, display


def init_style():
    """Set stylesheet and rc parameters for the notebook."""
    set_stylesheet()
    set_rc_params()


def set_rc_params():
    """Set figure rendering parameters."""
    mpl.rcParams["figure.figsize"] = (10.0, 6.0)
    mpl.rcParams["figure.dpi"] = 100
    mpl.rcParams["savefig.dpi"] = 300


def _get_stylesheet() -> HTML:
    """Return stylesheet for the Jupyter notebook.

    Just call this function at the beginning of the notebook to set the style.

    Returns
    -------

    HTML code to be injected in the Jupyter notebook.
    """

    return


def set_stylesheet():
    """Set the stylesheet for the Jupyter notebook."""

    # Define and apply the stylesheet
    display(
        HTML(
            """
    <style>
    .container {
        width: 90% !important;
    }

    #notebook-container {
        box-shadow: none !important;
        background-color: white;
    }

    div.input_area {
        border: none;
        border-radius: 0;
        background: #f7f7f7;
        line-height: 1.5em;
        margin: 0.5em 0;
        padding: 0;
    }

    div.cell {
        transition: all 0.25s;
        border: none;
        position: relative;
        top: 0;
    }

    div.cell.selected, div.cell.selected.jupyter-soft-selected {
        border: none;
        background: transparent;
        box-shadow: 0 6px 18px #aaa;
        z-index: 10;
        top: -10px;
    }

    .rendered_html p, ul {
        line-height: 1.5em;
        font-size: 16px;
    }

    .output_png {
        display: table-cell;
        text-align: center;
        vertical-align: middle;
    }

    </style>
    """
        )
    )
